@@ -1,4 +1,4 @@
-def enhanced_dir(arg, categorize=True, show_types=False, checks=False, collections_abc_list=False):
+def enhanced_dir(arg, categorize=True, show_types=False, checks=False, interfaces_and_types=False):
     from collections import defaultdict
     if not categorize:
         return_list = []
@@ -26,8 +26,9 @@ def enhanced_dir(arg, categorize=True, show_types=False, checks=False, collectio
         return_list = [{'passed': passed}, {'failed': failed}]
     if show_types:
         return_list.extend(({'passed_types': passed_}, {'failed_types': failed_}))
-    if collections_abc_list:
+    if interfaces_and_types:
         import collections.abc
+        import types
         collections_abc = {*()}
         for i in dir(collections.abc):
             try:
@@ -35,7 +36,15 @@ def enhanced_dir(arg, categorize=True, show_types=False, checks=False, collectio
                     collections_abc.add(i)
             except:
                 pass
-        return_list.append([collections_abc])
+        return_list.append({'collections_abc': collections_abc})
+        types_ = {*()}
+        for i in dir(types):
+            try:
+                if isinstance(arg, eval(f'types.{i}')):
+                    types_.add(i)
+            except:
+                pass
+        return_list.append({'types': types_})
     if checks:
         checks_ = {}
         try:
@@ -179,11 +188,11 @@ def operator_check(left_argument, right_argument, show_failed=False):
 
 extended_builtins = ['Ellipsis', 'False', 'None', 'NotImplemented', 'True', 'abs', 'all', 'any',
                      'ascii', 'bin', 'bool', 'breakpoint', 'bytearray', 'bytes', 'callable', 'chr',
-                     'classmethod', 'compile', 'complex', 'copyright', 'credits', 'delattr', 'dict',
-                     'dir', 'display', 'divmod', 'dreload', 'enumerate', 'eval', 'exec', 'execfile',
+                     'classmethod', 'compile', 'complex', 'delattr', 'dict',
+                     'dir', 'display', 'divmod', 'enumerate', 'eval', 'exec', 'execfile',
                      'filter', 'float', 'format', 'frozenset', 'getattr', 'globals', 'hasattr',
-                     'hash', 'help', 'hex', 'id', 'input', 'int', 'isinstance', 'issubclass',
-                     'iter', 'len', 'license', 'list', 'locals', 'map', 'max', 'memoryview', 'min',
+                     'hash', 'hex', 'id', 'input', 'int', 'isinstance', 'issubclass',
+                     'iter', 'len', 'list', 'locals', 'map', 'max', 'memoryview', 'min',
                      'next', 'object', 'oct', 'open', 'ord', 'pow', 'print', 'property', 'range',
                      'repr', 'reversed', 'round', 'runfile', 'set', 'setattr', 'slice', 'sorted',
                      'staticmethod', 'str', 'sum', 'super', 'tuple', 'type', 'vars', 'zip',
@@ -193,3 +202,10 @@ extended_builtins = ['Ellipsis', 'False', 'None', 'NotImplemented', 'True', 'abs
                      '(iter(()))', '(iter(zip()))', '(lambda x: 1).__code__.co_lines',
                      '(lambda x: 1).__code__.co_positions', '(type.__dict__)',
                      '((lambda: (yield))())', 'dict().keys', 'dict().values', 'dict().items']
+
+external_checks = {'imports': 'from collections import Counter, namedtuple, defaultdict, OrderedDict;\
+                               from types import SimpleNamespace;\
+                               from fractions import Fraction;\
+                               from decimal import Decimal;',
+                   'modules': ['Counter', 'Fraction', 'Decimal', 'defaultdict', 'OrderedDict', 'namedtuple',
+                               'SimpleNamespace']}
